import sqlalchemy as sa
from efa.model.outputindicator import Outputindicator
from formbar.form import Form
from ringo.model import Base
from ringo.lib.form import get_form_config



class QEOutputindicator(Outputindicator):
    """Waskiq specific Outputindicators. Adds some local fields.
    """

    qeparticipation = sa.orm.relation(
        "Participation",
        enable_typechecks=False,
        backref=sa.orm.backref("qeoi",
                               uselist=False,
                               cascade="all"))

    # Status of the outputindicators
    status = sa.Column('status', sa.Integer)
    qe_project_module = sa.Column('qe_project_module', sa.String)
    access_path = sa.Column('access_path', sa.Integer)
    access_path_others = sa.Column('access_path_others', sa.String, nullable=True, default='')
    lm_employment_supportpurchased = sa.Column('lm_employment_supportpurchased', sa.Integer)
    lm_employment_category_unemployed = sa.Column('lm_employment_category_unemployed', sa.Integer)
    lm_employment_category_unemployement_duration = sa.Column('lm_employment_category_unemployement_duration', sa.Integer)
    lm_employment_category_unemployment_type = sa.Column('lm_employment_category_unemployment_type', sa.Integer)
    lm_employment_category_lookingforwork = sa.Column('lm_employment_category_lookingforwork', sa.Integer)
    lm_employment_category_employed = sa.Column('lm_employment_category_employed', sa.Integer)
    lm_employment_category_underemployed = sa.Column('lm_employment_category_underemployed', sa.Integer)
    lm_employment_category_selfemployed = sa.Column('lm_employment_category_selfemployed', sa.Integer)
    lm_employment_category_school = sa.Column('lm_employment_category_school', sa.Integer)
    lm_employment_category_education_enterprise = sa.Column('lm_employment_category_education_enterprise', sa.Integer)
    lm_employment_category_education_school = sa.Column('lm_employment_category_education_school', sa.Integer)
    lm_employment_category_fulltime_student = sa.Column('lm_employment_category_fulltime_student', sa.Integer)
    lm_employment_category_training = sa.Column('lm_employment_category_training', sa.Integer)
    lm_employment_category_inactive = sa.Column('lm_employment_category_inactive', sa.Integer)
    edu_attainment_school = sa.Column('edu_attainment_school', sa.Integer)
    edu_attainment_school_germany = sa.Column('edu_attainment_school_germany', sa.Integer)
    edu_attainment_school_recognized = sa.Column('edu_attainment_school_recognized', sa.Integer)
    edu_attainment_vocational = sa.Column('edu_attainment_vocational', sa.Integer)
    edu_attainment_vocational_germany = sa.Column('edu_attainment_vocational_germany', sa.Integer)
    edu_attainment_vocational_recognized = sa.Column('edu_attainment_vocational_recognized', sa.Integer)
    edu_attaiment_vocational_outside_category_other = sa.Column('edu_attaiment_vocational_outside_category_other', sa.String, nullable=True, default='')
    work_experience_abroad = sa.Column('work_experience_abroad', sa.Integer)
    work_experience_germany = sa.Column('work_experience_germany', sa.Integer)
    industry = sa.Column('industry', sa.String)
    born_germany = sa.Column('born_germany', sa.Integer)
    moving_in = sa.Column('moving_in', sa.Integer)
    misc_german_nationality = sa.Column('misc_german_nationality', sa.Integer)
    emigrant = sa.Column('emigrant', sa.Integer)
    country_origin = sa.Column('country_origin', sa.String, nullable=True, default='')
    residence_permit_status = sa.Column('residence_permit_status', sa.Integer)
    residence_permit_purpose = sa.Column('residence_permit_purpose', sa.Integer)
    integration_course = sa.Column('integration_course', sa.Integer)
    german_knowledge = sa.Column('german_knowledge', sa.Integer)
    da_resident = sa.Column('da_resident', sa.Integer)
    jobcenter_job_search = sa.Column('jobcenter_job_search', sa.Integer)
    job_search_assistance = sa.Column('job_search_assistance', sa.Integer)
    job_center_help = sa.Column('job_center_help', sa.Integer)
    children_age = sa.Column('children_age', sa.String)
    edu_attaiment_vocational_outside = sa.Column(
            'edu_attaiment_vocational_outside', sa.Integer)
    edu_attaiment_vocational_outside_category = sa.Column(
            'edu_attaiment_vocational_outside_category', sa.Integer)
    edu_attaiment_vocational_outside_category_academic = sa.Column(
            'edu_attaiment_vocational_outside_category_academic', sa.String)
    edu_attaiment_vocational_inside_category = sa.Column(
            'edu_attaiment_vocational_inside_category', sa.Integer)
    edu_attaiment_vocational_inside_category_other = sa.Column(
            'edu_attaiment_vocational_inside_category_other',
            sa.String)
    edu_vocational_xp_all = sa.Column('edu_vocational_xp_all', sa.Integer)
    edu_vocational_xp_in_job = sa.Column('edu_vocational_xp_in_job',
            sa.Integer)
    edu_vocational_xp_after_school_in_job = sa.Column(
            "edu_vocational_xp_after_school_in_job", sa.Integer)
    edu_vocational_xp_education = sa.Column(
            'edu_vocational_xp_education', sa.Integer)
    project_working_time = sa.Column('project_working_time', sa.Integer)
    learning_place_school = sa.Column('learning_place_school', sa.Integer)
    learning_place_practise = sa.Column('learning_place_practise', sa.Integer)
    learning_self = sa.Column('learning_self', sa.Integer)

    def is_complete(self):
        if self.status is not None:
            if self.status == 1:
                return True
            else:
                return False
        form_config = get_form_config(self, "update")
        form = Form(form_config, self)
        form.validate()

        status = not form.has_errors() and not form.has_warnings()
        if status:
            self.status = 1
        else:
            self.status = 0
        return status
